WrapCased

Trait WrapCased 

pub trait WrapCased {
    type Wrapper<S: CaseSensitivity>;

    // Required methods
    fn case_sensitive(self) -> Self::Wrapper<CaseSensitive>;
    fn case_insensitive(self) -> Self::Wrapper<CaseInsensitive>;
}
Wraps Self in a type that affects the case sensitivity of operations

Using methods of CaseSensitivity in Wrapper implementations are not mandotary. They are provided mostly for convenience and to have a common implementation for comparisons

Required Associated Types

type Wrapper<S: CaseSensitivity>

Wrapper type generic over case sensitivity.

Required Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors