Module config

Module config 

Module containing the internal representation of user configuration

Structs

ClipConfig
CompletionConfig
Config
CursorShapeConfig
DatetimeFormatConfig
DisplayErrors
ExternalCompleterConfig
FilesizeConfig
HistoryConfig
Hooks
Definition of a parsed hook from the config object
LsConfig
ParsedKeybinding
Definition of a parsed keybinding from the config object
ParsedMenu
Definition of a parsed menu from the config object
PluginGcConfig
Configures when a plugin should be stopped if inactive
PluginGcConfigs
Configures when plugins should be stopped if inactive
RmConfig
ShellIntegrationConfig
TableConfig
TableIndent

Enums

BannerKind
Option: show_banner
CompletionAlgorithm
CompletionSort
EditBindings
ErrorStyle
FooterMode
HistoryFileFormat
NuCursorShape
Definition of a Nushell CursorShape (to be mapped to crossterm::cursor::CursorShape)
TableIndexMode
TableMode
TrimStrategy
A Table view configuration, for a situation where we need to limit cell width in order to adjust for a terminal size.
UseAnsiColoring

Functions

extract_value