pub struct Call<'a> {
pub head: Span,
pub decl_id: DeclId,
pub inner: CallImpl<'a>,
}Expand description
This is a HACK to help Command support both the old AST evaluator and the
new IR evaluator at the same time. It should be removed once we are satisfied with the new
evaluator.
Fields
head: Spandecl_id: DeclIdinner: CallImpl<'a>Implementations
Sourceimpl Call<'_>
impl Call<'_>
Sourcepub fn new(span: Span) -> Self
pub fn new(span: Span) -> Self
Returns a new AST call with the given span. This is often used by commands that need an empty call to pass to a command. It’s not easily possible to add anything to this.
Sourcepub fn to_owned(&self) -> Call<'static>
pub fn to_owned(&self) -> Call<'static>
Convert the Call from any lifetime into 'static, by cloning the data within onto the
heap.
Sourcepub fn has_flag_const(
&self,
working_set: &StateWorkingSet<'_>,
stack: &Stack,
flag_name: &str,
) -> Result<bool, ShellError>
pub fn has_flag_const( &self, working_set: &StateWorkingSet<'_>, stack: &Stack, flag_name: &str, ) -> Result<bool, ShellError>
Check if a boolean flag is set at const-eval time.
Sourcepub fn get_flag_const<T: FromValue>(
&self,
working_set: &StateWorkingSet<'_>,
stack: &Stack,
name: &str,
) -> Result<Option<T>, ShellError>
pub fn get_flag_const<T: FromValue>( &self, working_set: &StateWorkingSet<'_>, stack: &Stack, name: &str, ) -> Result<Option<T>, ShellError>
Get a typed named argument at const-eval time.
Sourcepub fn req_const<T: FromValue>(
&self,
working_set: &StateWorkingSet<'_>,
stack: &Stack,
pos: usize,
) -> Result<T, ShellError>
pub fn req_const<T: FromValue>( &self, working_set: &StateWorkingSet<'_>, stack: &Stack, pos: usize, ) -> Result<T, ShellError>
Get a required positional argument at const-eval time.
Sourcepub fn rest_const<T: FromValue>(
&self,
working_set: &StateWorkingSet<'_>,
stack: &Stack,
starting_pos: usize,
) -> Result<Vec<T>, ShellError>
pub fn rest_const<T: FromValue>( &self, working_set: &StateWorkingSet<'_>, stack: &Stack, starting_pos: usize, ) -> Result<Vec<T>, ShellError>
Get the rest of the positional arguments at const-eval time.
Sourcepub fn arguments_span(&self) -> Span
pub fn arguments_span(&self) -> Span
Returns a span covering the call’s arguments.
Sourcepub fn get_parser_info<'a>(
&'a self,
stack: &'a Stack,
name: &str,
) -> Option<&'a Expression>
pub fn get_parser_info<'a>( &'a self, stack: &'a Stack, name: &str, ) -> Option<&'a Expression>
Get a parser info argument by name.
Sourcepub fn rest_iter_flattened(
&self,
engine_state: &EngineState,
stack: &mut Stack,
eval_expression: fn(&EngineState, &mut Stack, &Expression) -> Result<Value, ShellError>,
starting_pos: usize,
) -> Result<Vec<Value>, ShellError>
pub fn rest_iter_flattened( &self, engine_state: &EngineState, stack: &mut Stack, eval_expression: fn(&EngineState, &mut Stack, &Expression) -> Result<Value, ShellError>, starting_pos: usize, ) -> Result<Vec<Value>, ShellError>
Evaluator-agnostic implementation of rest_iter_flattened(). Evaluates or gets all of the
positional and spread arguments, flattens spreads, and then returns one list of values.
Sourcepub fn positional_nth<'a>(
&'a self,
stack: &'a Stack,
index: usize,
) -> Option<&'a Expression>
pub fn positional_nth<'a>( &'a self, stack: &'a Stack, index: usize, ) -> Option<&'a Expression>
Get the original AST expression for a positional argument.
Under IR this is usually None: argument AST is not retained for builtins.