pub enum ParseError {
Show 91 variants
ExtraTokens(Span),
ExtraTokensAfterClosingDelimiter(Span),
ExtraPositional(String, Span),
RequiredAfterOptional(String, Span),
UnexpectedEof(String, Span),
Unclosed(&'static str, Span, Span, String),
Unbalanced(&'static str, &'static str, Span, String),
Expected(&'static str, Span),
ExpectedWithStringMsg(String, Span),
ExpectedWithDidYouMean(&'static str, DidYouMean, Span),
InputMismatch(String, Span),
OutputMismatch(Type, String, Span),
Mismatch(String, String, Span),
ShellAndAnd(Span),
ShellOrOr(Span),
ShellErrRedirect(Span),
ShellOutErrRedirect(Span),
MultipleRedirections(RedirectionSource, Span, Span),
UnexpectedRedirection {
span: Span,
},
OperatorUnsupportedType {
op: &'static str,
unsupported: Type,
op_span: Span,
unsupported_span: Span,
help: Option<&'static str>,
},
OperatorIncompatibleTypes {
op: &'static str,
lhs: Type,
rhs: Type,
op_span: Span,
lhs_span: Span,
rhs_span: Span,
help: Option<&'static str>,
},
CaptureOfMutableVar(Span),
ExpectedKeyword(String, Span),
UnexpectedKeyword(String, Span),
KeywordShadowModuleMain(String, Span),
CantAliasKeyword(String, Span),
CantAliasExpression(String, Span),
UnknownOperator(&'static str, &'static str, Span),
BuiltinCommandInPipeline(String, Span),
AssignInPipeline(String, String, String, Span),
NameIsBuiltinVar(String, Span),
NameIsKeyword(String, String, Span),
IncorrectValue(String, Span, String),
InvalidBinaryString(Span, String),
MultipleRestParams(Span),
VariableNotFound(DidYouMean, Span),
EnvVarNotVar(String, Span),
VariableNotValid(Span),
AliasNotValid(Span),
CommandDefNotValid(Span),
ModuleNotFound(Span, String),
ModuleMissingModNuFile(String, Span),
CircularImport(String, Span),
NamedAsModule(String, String, String, Span),
ModuleDoubleMain(String, Span),
ExportMainAliasNotAllowed(Span),
ActiveOverlayNotFound(Span),
OverlayPrefixMismatch(String, String, Span),
ModuleOrOverlayNotFound(Span),
CantRemoveLastOverlay(Span),
CantHideDefaultOverlay(String, Span),
CantAddOverlayHelp(String, Span),
DuplicateCommandDef(Span),
UnknownCommand(Span),
NonUtf8(Span),
UnknownFlag(String, String, Span, String),
UnknownType(Span),
MissingFlagParam(String, Span),
OnlyLastFlagInBatchCanTakeArg(Span),
MissingPositional(String, Span, String),
KeywordMissingArgument(String, String, Span),
MissingType(Span),
TypeMismatch(Type, Type, Span),
TypeMismatchHelp(Type, Type, Span, String),
MissingRequiredFlag(String, Span),
IncompleteMathExpression(Span),
UnknownState(String, Span),
InternalError(String, Span),
IncompleteParser(Span),
RestNeedsName(Span),
ParameterMismatchType(String, String, String, Span),
NonConstantDefaultValue(Span),
ExtraColumns(usize, Span),
MissingColumns(usize, Span),
AssignmentMismatch(String, String, Span),
WrongImportPattern(String, Span),
ExportNotFound(Span),
SourcedFileNotFound(String, Span),
ScriptFileTooLarge {
path: String,
size: u64,
max_size: u64,
span: Span,
},
ScriptFileNotText {
path: String,
span: Span,
},
RegisteredFileNotFound(String, Span),
FileNotFound(String, Span),
PluginNotFound {
name: String,
name_span: Span,
plugin_config_span: Option<Span>,
},
InvalidLiteral(String, String, Span),
LabeledError(String, String, Span),
LabeledErrorWithHelp {
error: String,
label: String,
help: String,
span: Span,
},
RedirectingBuiltinCommand(&'static str, Span, Option<Span>),
UnexpectedSpreadArg(String, Span),
AssignmentRequiresMutableVar(Span),
AssignmentRequiresVar(Span),
AttributeRequiresDefinition(Span),
}Variants
ExtraTokens(Span)
The parser encountered unexpected tokens, when the code should have finished. You should remove these or finish adding what you intended to add.
ExtraTokensAfterClosingDelimiter(Span)
ExtraPositional(String, Span)
RequiredAfterOptional(String, Span)
UnexpectedEof(String, Span)
Unclosed(&'static str, Span, Span, String)
A delimiter was opened but never closed.
0: expected closer (e.g."}","]",")")1: span of the opening delimiter2: span where the closer was expected (primary — often mid-file or EOF)3: help text (generic or heuristic structure hint)
Primary label is the expected closer location so a deleted } near
line N points the user at (or near) line N, not only at a distant opener.
Unbalanced(&'static str, &'static str, Span, String)
A closer appeared without a matching opener (or mismatched kind).
0/1: open and close delimiter characters (e.g."{","}")2: span of the unexpected closer (primary label)3: help text
Expected(&'static str, Span)
ExpectedWithStringMsg(String, Span)
ExpectedWithDidYouMean(&'static str, DidYouMean, Span)
InputMismatch(String, Span)
OutputMismatch(Type, String, Span)
Mismatch(String, String, Span)
ShellAndAnd(Span)
ShellOrOr(Span)
ShellErrRedirect(Span)
ShellOutErrRedirect(Span)
MultipleRedirections(RedirectionSource, Span, Span)
UnexpectedRedirection
OperatorUnsupportedType
One or more of the values have types not supported by the operator.
Fields
OperatorIncompatibleTypes
The operator supports the types of both values, but not the specific combination of their types.
Fields
CaptureOfMutableVar(Span)
ExpectedKeyword(String, Span)
UnexpectedKeyword(String, Span)
KeywordShadowModuleMain(String, Span)
CantAliasKeyword(String, Span)
CantAliasExpression(String, Span)
UnknownOperator(&'static str, &'static str, Span)
BuiltinCommandInPipeline(String, Span)
AssignInPipeline(String, String, String, Span)
NameIsBuiltinVar(String, Span)
NameIsKeyword(String, String, Span)
IncorrectValue(String, Span, String)
InvalidBinaryString(Span, String)
MultipleRestParams(Span)
VariableNotFound(DidYouMean, Span)
EnvVarNotVar(String, Span)
VariableNotValid(Span)
AliasNotValid(Span)
CommandDefNotValid(Span)
ModuleNotFound(Span, String)
ModuleMissingModNuFile(String, Span)
CircularImport(String, Span)
NamedAsModule(String, String, String, Span)
ModuleDoubleMain(String, Span)
ExportMainAliasNotAllowed(Span)
ActiveOverlayNotFound(Span)
OverlayPrefixMismatch(String, String, Span)
ModuleOrOverlayNotFound(Span)
CantRemoveLastOverlay(Span)
CantHideDefaultOverlay(String, Span)
CantAddOverlayHelp(String, Span)
DuplicateCommandDef(Span)
UnknownCommand(Span)
NonUtf8(Span)
UnknownFlag(String, String, Span, String)
UnknownType(Span)
MissingFlagParam(String, Span)
OnlyLastFlagInBatchCanTakeArg(Span)
MissingPositional(String, Span, String)
KeywordMissingArgument(String, String, Span)
MissingType(Span)
TypeMismatch(Type, Type, Span)
TypeMismatchHelp(Type, Type, Span, String)
MissingRequiredFlag(String, Span)
IncompleteMathExpression(Span)
UnknownState(String, Span)
InternalError(String, Span)
IncompleteParser(Span)
RestNeedsName(Span)
ParameterMismatchType(String, String, String, Span)
NonConstantDefaultValue(Span)
ExtraColumns(usize, Span)
MissingColumns(usize, Span)
AssignmentMismatch(String, String, Span)
WrongImportPattern(String, Span)
ExportNotFound(Span)
SourcedFileNotFound(String, Span)
ScriptFileTooLarge
ScriptFileNotText
RegisteredFileNotFound(String, Span)
FileNotFound(String, Span)
PluginNotFound
InvalidLiteral(String, String, Span)
LabeledError(String, String, Span)
LabeledErrorWithHelp
RedirectingBuiltinCommand(&'static str, Span, Option<Span>)
UnexpectedSpreadArg(String, Span)
AssignmentRequiresMutableVar(Span)
Invalid assignment left-hand side
Resolution
Assignment requires that you assign to a mutable variable or cell path.
AssignmentRequiresVar(Span)
Invalid assignment left-hand side
Resolution
Assignment requires that you assign to a variable or variable cell path.
AttributeRequiresDefinition(Span)
Implementations
Sourceimpl ParseError
impl ParseError
Sourcepub fn opener_span(span: Span, len: usize) -> Span
pub fn opener_span(span: Span, len: usize) -> Span
Span covering the first len bytes of span (clamped to span.end).
Used when labeling a multi-byte construct’s opening delimiter.
Sourcepub fn unclosed(
delimiter: &'static str,
open_span: Span,
end_span: Span,
) -> Self
pub fn unclosed( delimiter: &'static str, open_span: Span, end_span: Span, ) -> Self
Build an Unclosed with default help text.
Sourcepub fn unclosed_with_hint(
delimiter: &'static str,
open_span: Span,
end_span: Span,
structure_hint: Option<&str>,
) -> Self
pub fn unclosed_with_hint( delimiter: &'static str, open_span: Span, end_span: Span, structure_hint: Option<&str>, ) -> Self
Build an Unclosed with an optional structure hint
(e.g. record field ls, def foo). Empty/None uses generic help.
Sourcepub fn unbalanced(
open: &'static str,
close: &'static str,
close_span: Span,
) -> Self
pub fn unbalanced( open: &'static str, close: &'static str, close_span: Span, ) -> Self
Build an Unbalanced with default help text.
pub fn span(&self) -> Span