pub enum Type {
Show 22 variants
Any,
Binary,
Block,
Bool,
CellPath,
Closure,
Custom(Box<str>),
Date,
Duration,
Error,
Filesize,
Float,
Int,
List(Box<Type>),
Nothing,
Number,
OneOf(OneOf),
Range,
Record(CollectionColumns<Type>),
String,
Glob,
Table(CollectionColumns<Type>),
}Variants
Any
Top type, supertype of all types
Binary
Block
Bool
CellPath
Closure
Custom(Box<str>)
Date
Duration
Error
Filesize
Float
Int
List(Box<Type>)
Nothing
Number
Supertype of Int and Float. Equivalent to oneof<int, float>
OneOf(OneOf)
Supertype of all types it contains.
Range
Record(CollectionColumns<Type>)
String
Glob
Table(CollectionColumns<Type>)
Implementations
Sourceimpl Type
impl Type
pub fn list(inner: Type) -> Self
Sourcepub fn one_of(types: impl IntoIterator<Item = Type>) -> Self
pub fn one_of(types: impl IntoIterator<Item = Type>) -> Self
Creates a OneOf type from an iterator of types. Flattens any nested OneOf types and removes duplicates.
pub fn record() -> Self
pub fn table() -> Self
pub fn custom(name: impl Into<Box<str>>) -> Self
Sourcepub fn supertype_of(it: impl IntoIterator<Item = Type>) -> Option<Self>
pub fn supertype_of(it: impl IntoIterator<Item = Type>) -> Option<Self>
Returns a supertype of all types within it that is not Any.
If it contains Type::Any, short circuits and returns None.
pub fn is_numeric(&self) -> bool
pub fn is_list(&self) -> bool
Sourcepub fn accepts_cell_paths(&self) -> bool
pub fn accepts_cell_paths(&self) -> bool
Does this type represent a data structure containing values that can be addressed using ‘cell paths’?
pub fn to_shape(&self) -> SyntaxShape
Sourcepub fn get_non_specified_string(&self) -> String
pub fn get_non_specified_string(&self) -> String
Get a string representation, without inner type specification of lists,
tables and records (get list instead of list<any>
pub fn follow_cell_path<'a>( &'a self, path_members: &'a [PathMember], ) -> Option<Cow<'a, Self>>