pub enum TypeRelation {
Subtype,
Equal,
Supertype,
}Variants
Implementations
Sourceimpl TypeRelation
impl TypeRelation
pub fn reverse(self) -> Self
Sourcepub fn combine(self, other: Self) -> Option<Self>
pub fn combine(self, other: Self) -> Option<Self>
Combines two partial relation results.
While computing the relation of two types, sometimes it has to be done in multiple steps,
e.g. oneof, record.
- In both cases, one may start with
Self::Equalbefore processing any type parameters. - If both types are empty (e.g.
record<>with no columns,oneof<>with no variants),Self::Equalis the correct result without requiring further checks. - As items are checked, the result of these checks may not form a coherent result.
e.g.:
lhs = record<a: int, b: int>andrhs = record<a: int, c: int>- both
lhsandrhshave ana: intcolumn.lhsandrhsmight be Equal lhshas ab: intcolumn, whichrhsdoes not. This makeslhsthe more specific type between the two, thuslhsmight be a Subtype ofrhslhsdoes not have ab: intcolumn, whichrhsdoes. This makesrhsthe more specific type between the two, thuslhsmight be a Supertype ofrhs
- both
- If there are conflicting results, returns
None