This module manages the step of turning error types into printed error messages
Relies on the miette crate for pretty layout
Structs
- Report
Log - A bloom-filter like structure to store the hashes of warnings, without actually permanently storing the entire warning in memory. May rarely result in warnings incorrectly being unreported upon hash collision.
Enums
- Report
Mode - How a warning/error should be reported
Statics
- SUPPRESS_
REPORTING - While doing in-process testing of Nushell, the reports may spam the console output.
Traits
- Reportable
- For warnings/errors which have a ReportMode that dictates when they are reported