Module shell_error

Module shell_error 

Modules

bridge
generic
io
job
network

Structs

ErrorSource

Enums

ErrorSite
Represents where an error originated.
ShellError
The fundamental error type for the evaluation engine. These cases represent different kinds of errors the evaluator might face, along with helpful spans to label. An error renderer will take this error value and pass it into an error viewer to display to the user.