pub struct PipelineMetadata {
pub data_source: DataSource,
pub path_columns: Vec<String>,
pub content_type: Option<String>,
pub custom: Record,
}Expand description
Metadata that is valid for the whole PipelineData
Custom Metadata
The custom field allows commands and plugins to attach arbitrary metadata to pipeline data.
To avoid key collisions, it is recommended to use namespaced keys with an underscore separator:
"http_response"- HTTP response metadata (status, headers, etc.)"polars_schema"- DataFrame schema information"custom_plugin_field"- Plugin-specific metadata
This convention helps ensure different commands and plugins don’t overwrite each other’s metadata.
Fields
data_source: DataSourcepath_columns: Vec<String>content_type: Option<String>custom: RecordImplementations
Sourceimpl PipelineMetadata
impl PipelineMetadata
pub fn with_data_source(self, data_source: DataSource) -> Self
pub fn with_path_columns(self, path_columns: Vec<String>) -> Self
pub fn with_content_type(self, content_type: Option<String>) -> Self
Sourcepub fn set_table_width_priority_columns<I, S>(&mut self, span: Span, columns: I)
pub fn set_table_width_priority_columns<I, S>(&mut self, span: Span, columns: I)
Set table width-priority columns in custom metadata.
This helper accepts plain strings to avoid manually constructing Value::list.
Sourcepub fn with_table_width_priority_columns<I, S>(
self,
span: Span,
columns: I,
) -> Self
pub fn with_table_width_priority_columns<I, S>( self, span: Span, columns: I, ) -> Self
Builder-style variant of PipelineMetadata::set_table_width_priority_columns.
Sourcepub fn for_collect(self) -> Option<Self>
pub fn for_collect(self) -> Option<Self>
Transform metadata for the collect operation.
After collecting a stream into a value, FilePath data sources are no longer meaningful
and should be converted to None. If all metadata fields become empty after this
transformation, returns None to avoid carrying around empty metadata.