Struct nu_protocol::value::value_structure::ValueResource
source · [−]Fields
at: usizeloc: PathBufTrait Implementations
sourceimpl Debug for ValueResource
impl Debug for ValueResource
sourceimpl Ord for ValueResource
impl Ord for ValueResource
sourceimpl PartialEq<ValueResource> for ValueResource
impl PartialEq<ValueResource> for ValueResource
sourcefn eq(&self, other: &ValueResource) -> bool
fn eq(&self, other: &ValueResource) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &ValueResource) -> bool
fn ne(&self, other: &ValueResource) -> bool
This method tests for !=.
sourceimpl PartialOrd<ValueResource> for ValueResource
impl PartialOrd<ValueResource> for ValueResource
sourcefn partial_cmp(&self, other: &ValueResource) -> Option<Ordering>
fn partial_cmp(&self, other: &ValueResource) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Eq for ValueResource
impl StructuralEq for ValueResource
impl StructuralPartialEq for ValueResource