pub struct PipelineExecutionData {
pub body: PipelineData,
pub exit: Vec<Option<ExitStatusGuard>>,
}Expand description
A wrapper to PipelineData which can also track exit status.
We use exit status tracking to implement the pipefail feature.
Fields
body: PipelineDataexit: Vec<Option<ExitStatusGuard>>Implementations
Methods from Deref<Target = PipelineData>
Sourcepub fn metadata(&self) -> Option<PipelineMetadata>
👎Deprecated since 0.111.1: Use .metadata_ref(), .metadata_mut() or .take_metadata() instead
pub fn metadata(&self) -> Option<PipelineMetadata>
Use .metadata_ref(), .metadata_mut() or .take_metadata() instead
Returns a clone of the metadata if it exists.
Note: This performs a deep clone of heap-allocated structures.
Use .metadata_ref(), .metadata_mut()
or .take_metadata() to avoid unnecessary allocations.
Sourcepub fn metadata_ref(&self) -> Option<&PipelineMetadata>
pub fn metadata_ref(&self) -> Option<&PipelineMetadata>
Returns a reference to the metadata if it exists.
Sourcepub fn metadata_mut(&mut self) -> Option<&mut PipelineMetadata>
pub fn metadata_mut(&mut self) -> Option<&mut PipelineMetadata>
Returns a mutable reference to the metadata if it exists.
Sourcepub fn take_metadata(&mut self) -> Option<PipelineMetadata>
pub fn take_metadata(&mut self) -> Option<PipelineMetadata>
Take the metadata out of pipeline if it exists.
pub fn is_nothing(&self) -> bool
Sourcepub fn get_type(&self) -> Type
pub fn get_type(&self) -> Type
Get a type that is representative of the PipelineData.
The type returned here makes no effort to collect a stream, so it may be a different type
than would be returned by Value::get_type() on the result of
.into_value().
Specifically, a ListStream results in list<any> rather than
the fully complete list type (which would require knowing the contents),
and a ByteStream with unknown type results in
any rather than string or binary.
pub fn clone_exit_status_future(&self) -> Option<ExitStatusGuard>